/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CloudProviderAccessSetupConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cloud_provider_access_setup#id CloudProviderAccessSetup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cloud_provider_access_setup#project_id CloudProviderAccessSetup#project_id}
    */
    readonly projectId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cloud_provider_access_setup#provider_name CloudProviderAccessSetup#provider_name}
    */
    readonly providerName: string;
    /**
    * azure_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cloud_provider_access_setup#azure_config CloudProviderAccessSetup#azure_config}
    */
    readonly azureConfig?: CloudProviderAccessSetupAzureConfig[] | cdktf.IResolvable;
}
export interface CloudProviderAccessSetupAwsConfig {
}
export declare function cloudProviderAccessSetupAwsConfigToTerraform(struct?: CloudProviderAccessSetupAwsConfig): any;
export declare function cloudProviderAccessSetupAwsConfigToHclTerraform(struct?: CloudProviderAccessSetupAwsConfig): any;
export declare class CloudProviderAccessSetupAwsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CloudProviderAccessSetupAwsConfig | undefined;
    set internalValue(value: CloudProviderAccessSetupAwsConfig | undefined);
    get atlasAssumedRoleExternalId(): string;
    get atlasAwsAccountArn(): string;
}
export declare class CloudProviderAccessSetupAwsConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CloudProviderAccessSetupAwsConfigOutputReference;
}
export interface CloudProviderAccessSetupAzureConfig {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cloud_provider_access_setup#atlas_azure_app_id CloudProviderAccessSetup#atlas_azure_app_id}
    */
    readonly atlasAzureAppId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cloud_provider_access_setup#service_principal_id CloudProviderAccessSetup#service_principal_id}
    */
    readonly servicePrincipalId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cloud_provider_access_setup#tenant_id CloudProviderAccessSetup#tenant_id}
    */
    readonly tenantId: string;
}
export declare function cloudProviderAccessSetupAzureConfigToTerraform(struct?: CloudProviderAccessSetupAzureConfig | cdktf.IResolvable): any;
export declare function cloudProviderAccessSetupAzureConfigToHclTerraform(struct?: CloudProviderAccessSetupAzureConfig | cdktf.IResolvable): any;
export declare class CloudProviderAccessSetupAzureConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CloudProviderAccessSetupAzureConfig | cdktf.IResolvable | undefined;
    set internalValue(value: CloudProviderAccessSetupAzureConfig | cdktf.IResolvable | undefined);
    private _atlasAzureAppId?;
    get atlasAzureAppId(): string;
    set atlasAzureAppId(value: string);
    get atlasAzureAppIdInput(): string | undefined;
    private _servicePrincipalId?;
    get servicePrincipalId(): string;
    set servicePrincipalId(value: string);
    get servicePrincipalIdInput(): string | undefined;
    private _tenantId?;
    get tenantId(): string;
    set tenantId(value: string);
    get tenantIdInput(): string | undefined;
}
export declare class CloudProviderAccessSetupAzureConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CloudProviderAccessSetupAzureConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CloudProviderAccessSetupAzureConfigOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cloud_provider_access_setup mongodbatlas_cloud_provider_access_setup}
*/
export declare class CloudProviderAccessSetup extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_cloud_provider_access_setup";
    /**
    * Generates CDKTF code for importing a CloudProviderAccessSetup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CloudProviderAccessSetup to import
    * @param importFromId The id of the existing CloudProviderAccessSetup that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cloud_provider_access_setup#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CloudProviderAccessSetup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cloud_provider_access_setup mongodbatlas_cloud_provider_access_setup} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CloudProviderAccessSetupConfig
    */
    constructor(scope: Construct, id: string, config: CloudProviderAccessSetupConfig);
    private _awsConfig;
    get awsConfig(): CloudProviderAccessSetupAwsConfigList;
    get createdDate(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastUpdatedDate(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _providerName?;
    get providerName(): string;
    set providerName(value: string);
    get providerNameInput(): string | undefined;
    get roleId(): string;
    private _azureConfig;
    get azureConfig(): CloudProviderAccessSetupAzureConfigList;
    putAzureConfig(value: CloudProviderAccessSetupAzureConfig[] | cdktf.IResolvable): void;
    resetAzureConfig(): void;
    get azureConfigInput(): cdktf.IResolvable | CloudProviderAccessSetupAzureConfig[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
