/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ClusterOutageSimulationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation#cluster_name ClusterOutageSimulation#cluster_name}
    */
    readonly clusterName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation#id ClusterOutageSimulation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation#project_id ClusterOutageSimulation#project_id}
    */
    readonly projectId: string;
    /**
    * outage_filters block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation#outage_filters ClusterOutageSimulation#outage_filters}
    */
    readonly outageFilters: ClusterOutageSimulationOutageFilters[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation#timeouts ClusterOutageSimulation#timeouts}
    */
    readonly timeouts?: ClusterOutageSimulationTimeouts;
}
export interface ClusterOutageSimulationOutageFilters {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation#cloud_provider ClusterOutageSimulation#cloud_provider}
    */
    readonly cloudProvider: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation#region_name ClusterOutageSimulation#region_name}
    */
    readonly regionName: string;
}
export declare function clusterOutageSimulationOutageFiltersToTerraform(struct?: ClusterOutageSimulationOutageFilters | cdktf.IResolvable): any;
export declare function clusterOutageSimulationOutageFiltersToHclTerraform(struct?: ClusterOutageSimulationOutageFilters | cdktf.IResolvable): any;
export declare class ClusterOutageSimulationOutageFiltersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ClusterOutageSimulationOutageFilters | cdktf.IResolvable | undefined;
    set internalValue(value: ClusterOutageSimulationOutageFilters | cdktf.IResolvable | undefined);
    private _cloudProvider?;
    get cloudProvider(): string;
    set cloudProvider(value: string);
    get cloudProviderInput(): string | undefined;
    private _regionName?;
    get regionName(): string;
    set regionName(value: string);
    get regionNameInput(): string | undefined;
    get type(): string;
}
export declare class ClusterOutageSimulationOutageFiltersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ClusterOutageSimulationOutageFilters[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ClusterOutageSimulationOutageFiltersOutputReference;
}
export interface ClusterOutageSimulationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation#delete ClusterOutageSimulation#delete}
    */
    readonly delete?: string;
}
export declare function clusterOutageSimulationTimeoutsToTerraform(struct?: ClusterOutageSimulationTimeouts | cdktf.IResolvable): any;
export declare function clusterOutageSimulationTimeoutsToHclTerraform(struct?: ClusterOutageSimulationTimeouts | cdktf.IResolvable): any;
export declare class ClusterOutageSimulationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ClusterOutageSimulationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: ClusterOutageSimulationTimeouts | cdktf.IResolvable | undefined);
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation mongodbatlas_cluster_outage_simulation}
*/
export declare class ClusterOutageSimulation extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_cluster_outage_simulation";
    /**
    * Generates CDKTF code for importing a ClusterOutageSimulation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ClusterOutageSimulation to import
    * @param importFromId The id of the existing ClusterOutageSimulation that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ClusterOutageSimulation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/cluster_outage_simulation mongodbatlas_cluster_outage_simulation} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ClusterOutageSimulationConfig
    */
    constructor(scope: Construct, id: string, config: ClusterOutageSimulationConfig);
    private _clusterName?;
    get clusterName(): string;
    set clusterName(value: string);
    get clusterNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    get simulationId(): string;
    get startRequestDate(): string;
    get state(): string;
    private _outageFilters;
    get outageFilters(): ClusterOutageSimulationOutageFiltersList;
    putOutageFilters(value: ClusterOutageSimulationOutageFilters[] | cdktf.IResolvable): void;
    get outageFiltersInput(): cdktf.IResolvable | ClusterOutageSimulationOutageFilters[] | undefined;
    private _timeouts;
    get timeouts(): ClusterOutageSimulationTimeoutsOutputReference;
    putTimeouts(value: ClusterOutageSimulationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | ClusterOutageSimulationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
