/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataMongodbatlasStreamProcessorConfig extends cdktf.TerraformMetaArguments {
    /**
    * Human-readable label that identifies the stream instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processor#instance_name DataMongodbatlasStreamProcessor#instance_name}
    */
    readonly instanceName: string;
    /**
    * Human-readable label that identifies the stream processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processor#processor_name DataMongodbatlasStreamProcessor#processor_name}
    */
    readonly processorName: string;
    /**
    * Unique 24-hexadecimal digit string that identifies your project. Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.
    *
    * **NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group/project id remains the same. The resource and corresponding endpoints use the term groups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processor#project_id DataMongodbatlasStreamProcessor#project_id}
    */
    readonly projectId: string;
}
export interface DataMongodbatlasStreamProcessorOptionsDlq {
}
export declare function dataMongodbatlasStreamProcessorOptionsDlqToTerraform(struct?: DataMongodbatlasStreamProcessorOptionsDlq): any;
export declare function dataMongodbatlasStreamProcessorOptionsDlqToHclTerraform(struct?: DataMongodbatlasStreamProcessorOptionsDlq): any;
export declare class DataMongodbatlasStreamProcessorOptionsDlqOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataMongodbatlasStreamProcessorOptionsDlq | undefined;
    set internalValue(value: DataMongodbatlasStreamProcessorOptionsDlq | undefined);
    get coll(): string;
    get connectionName(): string;
    get db(): string;
}
export interface DataMongodbatlasStreamProcessorOptions {
}
export declare function dataMongodbatlasStreamProcessorOptionsToTerraform(struct?: DataMongodbatlasStreamProcessorOptions): any;
export declare function dataMongodbatlasStreamProcessorOptionsToHclTerraform(struct?: DataMongodbatlasStreamProcessorOptions): any;
export declare class DataMongodbatlasStreamProcessorOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataMongodbatlasStreamProcessorOptions | undefined;
    set internalValue(value: DataMongodbatlasStreamProcessorOptions | undefined);
    private _dlq;
    get dlq(): DataMongodbatlasStreamProcessorOptionsDlqOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processor mongodbatlas_stream_processor}
*/
export declare class DataMongodbatlasStreamProcessor extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "mongodbatlas_stream_processor";
    /**
    * Generates CDKTF code for importing a DataMongodbatlasStreamProcessor resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataMongodbatlasStreamProcessor to import
    * @param importFromId The id of the existing DataMongodbatlasStreamProcessor that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processor#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataMongodbatlasStreamProcessor to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processor mongodbatlas_stream_processor} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataMongodbatlasStreamProcessorConfig
    */
    constructor(scope: Construct, id: string, config: DataMongodbatlasStreamProcessorConfig);
    get id(): string;
    private _instanceName?;
    get instanceName(): string;
    set instanceName(value: string);
    get instanceNameInput(): string | undefined;
    private _options;
    get options(): DataMongodbatlasStreamProcessorOptionsOutputReference;
    get pipeline(): string;
    private _processorName?;
    get processorName(): string;
    set processorName(value: string);
    get processorNameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    get state(): string;
    get stats(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
