/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataMongodbatlasStreamProcessorsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Human-readable label that identifies the stream instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processors#instance_name DataMongodbatlasStreamProcessors#instance_name}
    */
    readonly instanceName: string;
    /**
    * Unique 24-hexadecimal digit string that identifies your project. Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.
    *
    * **NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group/project id remains the same. The resource and corresponding endpoints use the term groups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processors#project_id DataMongodbatlasStreamProcessors#project_id}
    */
    readonly projectId: string;
}
export interface DataMongodbatlasStreamProcessorsResultsOptionsDlq {
}
export declare function dataMongodbatlasStreamProcessorsResultsOptionsDlqToTerraform(struct?: DataMongodbatlasStreamProcessorsResultsOptionsDlq): any;
export declare function dataMongodbatlasStreamProcessorsResultsOptionsDlqToHclTerraform(struct?: DataMongodbatlasStreamProcessorsResultsOptionsDlq): any;
export declare class DataMongodbatlasStreamProcessorsResultsOptionsDlqOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataMongodbatlasStreamProcessorsResultsOptionsDlq | undefined;
    set internalValue(value: DataMongodbatlasStreamProcessorsResultsOptionsDlq | undefined);
    get coll(): string;
    get connectionName(): string;
    get db(): string;
}
export interface DataMongodbatlasStreamProcessorsResultsOptions {
}
export declare function dataMongodbatlasStreamProcessorsResultsOptionsToTerraform(struct?: DataMongodbatlasStreamProcessorsResultsOptions): any;
export declare function dataMongodbatlasStreamProcessorsResultsOptionsToHclTerraform(struct?: DataMongodbatlasStreamProcessorsResultsOptions): any;
export declare class DataMongodbatlasStreamProcessorsResultsOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataMongodbatlasStreamProcessorsResultsOptions | undefined;
    set internalValue(value: DataMongodbatlasStreamProcessorsResultsOptions | undefined);
    private _dlq;
    get dlq(): DataMongodbatlasStreamProcessorsResultsOptionsDlqOutputReference;
}
export interface DataMongodbatlasStreamProcessorsResults {
}
export declare function dataMongodbatlasStreamProcessorsResultsToTerraform(struct?: DataMongodbatlasStreamProcessorsResults): any;
export declare function dataMongodbatlasStreamProcessorsResultsToHclTerraform(struct?: DataMongodbatlasStreamProcessorsResults): any;
export declare class DataMongodbatlasStreamProcessorsResultsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataMongodbatlasStreamProcessorsResults | undefined;
    set internalValue(value: DataMongodbatlasStreamProcessorsResults | undefined);
    get id(): string;
    get instanceName(): string;
    private _options;
    get options(): DataMongodbatlasStreamProcessorsResultsOptionsOutputReference;
    get pipeline(): string;
    get processorName(): string;
    get projectId(): string;
    get state(): string;
    get stats(): string;
}
export declare class DataMongodbatlasStreamProcessorsResultsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataMongodbatlasStreamProcessorsResultsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processors mongodbatlas_stream_processors}
*/
export declare class DataMongodbatlasStreamProcessors extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "mongodbatlas_stream_processors";
    /**
    * Generates CDKTF code for importing a DataMongodbatlasStreamProcessors resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataMongodbatlasStreamProcessors to import
    * @param importFromId The id of the existing DataMongodbatlasStreamProcessors that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processors#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataMongodbatlasStreamProcessors to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/data-sources/stream_processors mongodbatlas_stream_processors} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataMongodbatlasStreamProcessorsConfig
    */
    constructor(scope: Construct, id: string, config: DataMongodbatlasStreamProcessorsConfig);
    private _instanceName?;
    get instanceName(): string;
    set instanceName(value: string);
    get instanceNameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _results;
    get results(): DataMongodbatlasStreamProcessorsResultsList;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
