/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EncryptionAtRestConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique 24-hexadecimal digit string that identifies your project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#project_id EncryptionAtRest#project_id}
    */
    readonly projectId: string;
    /**
    * aws_kms_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#aws_kms_config EncryptionAtRest#aws_kms_config}
    */
    readonly awsKmsConfig?: EncryptionAtRestAwsKmsConfig[] | cdktf.IResolvable;
    /**
    * azure_key_vault_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#azure_key_vault_config EncryptionAtRest#azure_key_vault_config}
    */
    readonly azureKeyVaultConfig?: EncryptionAtRestAzureKeyVaultConfig[] | cdktf.IResolvable;
    /**
    * google_cloud_kms_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#google_cloud_kms_config EncryptionAtRest#google_cloud_kms_config}
    */
    readonly googleCloudKmsConfig?: EncryptionAtRestGoogleCloudKmsConfig[] | cdktf.IResolvable;
}
export interface EncryptionAtRestAwsKmsConfig {
    /**
    * Unique alphanumeric string that identifies an Identity and Access Management (IAM) access key with permissions required to access your Amazon Web Services (AWS) Customer Master Key (CMK).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#access_key_id EncryptionAtRest#access_key_id}
    */
    readonly accessKeyId?: string;
    /**
    * Unique alphanumeric string that identifies the Amazon Web Services (AWS) Customer Master Key (CMK) you used to encrypt and decrypt the MongoDB master keys.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#customer_master_key_id EncryptionAtRest#customer_master_key_id}
    */
    readonly customerMasterKeyId?: string;
    /**
    * Flag that indicates whether someone enabled encryption at rest for the specified project through Amazon Web Services (AWS) Key Management Service (KMS). To disable encryption at rest using customer key management and remove the configuration details, pass only this parameter with a value of `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#enabled EncryptionAtRest#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Physical location where MongoDB Atlas deploys your AWS-hosted MongoDB cluster nodes. The region you choose can affect network latency for clients accessing your databases. When MongoDB Cloud deploys a dedicated cluster, it checks if a VPC or VPC connection exists for that provider and region. If not, MongoDB Atlas creates them as part of the deployment. MongoDB Atlas assigns the VPC a CIDR block. To limit a new VPC peering connection to one CIDR block and region, create the connection first. Deploy the cluster after the connection starts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#region EncryptionAtRest#region}
    */
    readonly region?: string;
    /**
    * Unique 24-hexadecimal digit string that identifies an Amazon Web Services (AWS) Identity and Access Management (IAM) role. This IAM role has the permissions required to manage your AWS customer master key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#role_id EncryptionAtRest#role_id}
    */
    readonly roleId?: string;
    /**
    * Human-readable label of the Identity and Access Management (IAM) secret access key with permissions required to access your Amazon Web Services (AWS) customer master key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#secret_access_key EncryptionAtRest#secret_access_key}
    */
    readonly secretAccessKey?: string;
}
export declare function encryptionAtRestAwsKmsConfigToTerraform(struct?: EncryptionAtRestAwsKmsConfig | cdktf.IResolvable): any;
export declare function encryptionAtRestAwsKmsConfigToHclTerraform(struct?: EncryptionAtRestAwsKmsConfig | cdktf.IResolvable): any;
export declare class EncryptionAtRestAwsKmsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EncryptionAtRestAwsKmsConfig | cdktf.IResolvable | undefined;
    set internalValue(value: EncryptionAtRestAwsKmsConfig | cdktf.IResolvable | undefined);
    private _accessKeyId?;
    get accessKeyId(): string;
    set accessKeyId(value: string);
    resetAccessKeyId(): void;
    get accessKeyIdInput(): string | undefined;
    private _customerMasterKeyId?;
    get customerMasterKeyId(): string;
    set customerMasterKeyId(value: string);
    resetCustomerMasterKeyId(): void;
    get customerMasterKeyIdInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _roleId?;
    get roleId(): string;
    set roleId(value: string);
    resetRoleId(): void;
    get roleIdInput(): string | undefined;
    private _secretAccessKey?;
    get secretAccessKey(): string;
    set secretAccessKey(value: string);
    resetSecretAccessKey(): void;
    get secretAccessKeyInput(): string | undefined;
    get valid(): cdktf.IResolvable;
}
export declare class EncryptionAtRestAwsKmsConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: EncryptionAtRestAwsKmsConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EncryptionAtRestAwsKmsConfigOutputReference;
}
export interface EncryptionAtRestAzureKeyVaultConfig {
    /**
    * Azure environment in which your account credentials reside.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#azure_environment EncryptionAtRest#azure_environment}
    */
    readonly azureEnvironment?: string;
    /**
    * Unique 36-hexadecimal character string that identifies an Azure application associated with your Azure Active Directory tenant.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#client_id EncryptionAtRest#client_id}
    */
    readonly clientId?: string;
    /**
    * Flag that indicates whether someone enabled encryption at rest for the specified  project. To disable encryption at rest using customer key management and remove the configuration details, pass only this parameter with a value of `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#enabled EncryptionAtRest#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Web address with a unique key that identifies for your Azure Key Vault.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#key_identifier EncryptionAtRest#key_identifier}
    */
    readonly keyIdentifier?: string;
    /**
    * Unique string that identifies the Azure Key Vault that contains your key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#key_vault_name EncryptionAtRest#key_vault_name}
    */
    readonly keyVaultName?: string;
    /**
    * Enable connection to your Azure Key Vault over private networking.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#require_private_networking EncryptionAtRest#require_private_networking}
    */
    readonly requirePrivateNetworking?: boolean | cdktf.IResolvable;
    /**
    * Name of the Azure resource group that contains your Azure Key Vault.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#resource_group_name EncryptionAtRest#resource_group_name}
    */
    readonly resourceGroupName?: string;
    /**
    * Private data that you need secured and that belongs to the specified Azure Key Vault (AKV) tenant (**azureKeyVault.tenantID**). This data can include any type of sensitive data such as passwords, database connection strings, API keys, and the like. AKV stores this information as encrypted binary data.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#secret EncryptionAtRest#secret}
    */
    readonly secret?: string;
    /**
    * Unique 36-hexadecimal character string that identifies your Azure subscription.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#subscription_id EncryptionAtRest#subscription_id}
    */
    readonly subscriptionId?: string;
    /**
    * Unique 36-hexadecimal character string that identifies the Azure Active Directory tenant within your Azure subscription.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#tenant_id EncryptionAtRest#tenant_id}
    */
    readonly tenantId?: string;
}
export declare function encryptionAtRestAzureKeyVaultConfigToTerraform(struct?: EncryptionAtRestAzureKeyVaultConfig | cdktf.IResolvable): any;
export declare function encryptionAtRestAzureKeyVaultConfigToHclTerraform(struct?: EncryptionAtRestAzureKeyVaultConfig | cdktf.IResolvable): any;
export declare class EncryptionAtRestAzureKeyVaultConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EncryptionAtRestAzureKeyVaultConfig | cdktf.IResolvable | undefined;
    set internalValue(value: EncryptionAtRestAzureKeyVaultConfig | cdktf.IResolvable | undefined);
    private _azureEnvironment?;
    get azureEnvironment(): string;
    set azureEnvironment(value: string);
    resetAzureEnvironment(): void;
    get azureEnvironmentInput(): string | undefined;
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    resetClientId(): void;
    get clientIdInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _keyIdentifier?;
    get keyIdentifier(): string;
    set keyIdentifier(value: string);
    resetKeyIdentifier(): void;
    get keyIdentifierInput(): string | undefined;
    private _keyVaultName?;
    get keyVaultName(): string;
    set keyVaultName(value: string);
    resetKeyVaultName(): void;
    get keyVaultNameInput(): string | undefined;
    private _requirePrivateNetworking?;
    get requirePrivateNetworking(): boolean | cdktf.IResolvable;
    set requirePrivateNetworking(value: boolean | cdktf.IResolvable);
    resetRequirePrivateNetworking(): void;
    get requirePrivateNetworkingInput(): boolean | cdktf.IResolvable | undefined;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    resetResourceGroupName(): void;
    get resourceGroupNameInput(): string | undefined;
    private _secret?;
    get secret(): string;
    set secret(value: string);
    resetSecret(): void;
    get secretInput(): string | undefined;
    private _subscriptionId?;
    get subscriptionId(): string;
    set subscriptionId(value: string);
    resetSubscriptionId(): void;
    get subscriptionIdInput(): string | undefined;
    private _tenantId?;
    get tenantId(): string;
    set tenantId(value: string);
    resetTenantId(): void;
    get tenantIdInput(): string | undefined;
    get valid(): cdktf.IResolvable;
}
export declare class EncryptionAtRestAzureKeyVaultConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: EncryptionAtRestAzureKeyVaultConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EncryptionAtRestAzureKeyVaultConfigOutputReference;
}
export interface EncryptionAtRestGoogleCloudKmsConfig {
    /**
    * Flag that indicates whether someone enabled encryption at rest for the specified  project. To disable encryption at rest using customer key management and remove the configuration details, pass only this parameter with a value of `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#enabled EncryptionAtRest#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Resource path that displays the key version resource ID for your Google Cloud KMS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#key_version_resource_id EncryptionAtRest#key_version_resource_id}
    */
    readonly keyVersionResourceId?: string;
    /**
    * JavaScript Object Notation (JSON) object that contains the Google Cloud Key Management Service (KMS). Format the JSON as a string and not as an object.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#service_account_key EncryptionAtRest#service_account_key}
    */
    readonly serviceAccountKey?: string;
}
export declare function encryptionAtRestGoogleCloudKmsConfigToTerraform(struct?: EncryptionAtRestGoogleCloudKmsConfig | cdktf.IResolvable): any;
export declare function encryptionAtRestGoogleCloudKmsConfigToHclTerraform(struct?: EncryptionAtRestGoogleCloudKmsConfig | cdktf.IResolvable): any;
export declare class EncryptionAtRestGoogleCloudKmsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EncryptionAtRestGoogleCloudKmsConfig | cdktf.IResolvable | undefined;
    set internalValue(value: EncryptionAtRestGoogleCloudKmsConfig | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _keyVersionResourceId?;
    get keyVersionResourceId(): string;
    set keyVersionResourceId(value: string);
    resetKeyVersionResourceId(): void;
    get keyVersionResourceIdInput(): string | undefined;
    private _serviceAccountKey?;
    get serviceAccountKey(): string;
    set serviceAccountKey(value: string);
    resetServiceAccountKey(): void;
    get serviceAccountKeyInput(): string | undefined;
    get valid(): cdktf.IResolvable;
}
export declare class EncryptionAtRestGoogleCloudKmsConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: EncryptionAtRestGoogleCloudKmsConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EncryptionAtRestGoogleCloudKmsConfigOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest mongodbatlas_encryption_at_rest}
*/
export declare class EncryptionAtRest extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_encryption_at_rest";
    /**
    * Generates CDKTF code for importing a EncryptionAtRest resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the EncryptionAtRest to import
    * @param importFromId The id of the existing EncryptionAtRest that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the EncryptionAtRest to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/encryption_at_rest mongodbatlas_encryption_at_rest} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EncryptionAtRestConfig
    */
    constructor(scope: Construct, id: string, config: EncryptionAtRestConfig);
    get id(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _awsKmsConfig;
    get awsKmsConfig(): EncryptionAtRestAwsKmsConfigList;
    putAwsKmsConfig(value: EncryptionAtRestAwsKmsConfig[] | cdktf.IResolvable): void;
    resetAwsKmsConfig(): void;
    get awsKmsConfigInput(): cdktf.IResolvable | EncryptionAtRestAwsKmsConfig[] | undefined;
    private _azureKeyVaultConfig;
    get azureKeyVaultConfig(): EncryptionAtRestAzureKeyVaultConfigList;
    putAzureKeyVaultConfig(value: EncryptionAtRestAzureKeyVaultConfig[] | cdktf.IResolvable): void;
    resetAzureKeyVaultConfig(): void;
    get azureKeyVaultConfigInput(): cdktf.IResolvable | EncryptionAtRestAzureKeyVaultConfig[] | undefined;
    private _googleCloudKmsConfig;
    get googleCloudKmsConfig(): EncryptionAtRestGoogleCloudKmsConfigList;
    putGoogleCloudKmsConfig(value: EncryptionAtRestGoogleCloudKmsConfig[] | cdktf.IResolvable): void;
    resetGoogleCloudKmsConfig(): void;
    get googleCloudKmsConfigInput(): cdktf.IResolvable | EncryptionAtRestGoogleCloudKmsConfig[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
