/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FederatedDatabaseInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#id FederatedDatabaseInstance#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#name FederatedDatabaseInstance#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#project_id FederatedDatabaseInstance#project_id}
    */
    readonly projectId: string;
    /**
    * cloud_provider_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#cloud_provider_config FederatedDatabaseInstance#cloud_provider_config}
    */
    readonly cloudProviderConfig?: FederatedDatabaseInstanceCloudProviderConfig;
    /**
    * data_process_region block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#data_process_region FederatedDatabaseInstance#data_process_region}
    */
    readonly dataProcessRegion?: FederatedDatabaseInstanceDataProcessRegion;
    /**
    * storage_databases block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#storage_databases FederatedDatabaseInstance#storage_databases}
    */
    readonly storageDatabases?: FederatedDatabaseInstanceStorageDatabases[] | cdktf.IResolvable;
    /**
    * storage_stores block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#storage_stores FederatedDatabaseInstance#storage_stores}
    */
    readonly storageStores?: FederatedDatabaseInstanceStorageStores[] | cdktf.IResolvable;
}
export interface FederatedDatabaseInstanceCloudProviderConfigAws {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#role_id FederatedDatabaseInstance#role_id}
    */
    readonly roleId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#test_s3_bucket FederatedDatabaseInstance#test_s3_bucket}
    */
    readonly testS3Bucket: string;
}
export declare function federatedDatabaseInstanceCloudProviderConfigAwsToTerraform(struct?: FederatedDatabaseInstanceCloudProviderConfigAwsOutputReference | FederatedDatabaseInstanceCloudProviderConfigAws): any;
export declare function federatedDatabaseInstanceCloudProviderConfigAwsToHclTerraform(struct?: FederatedDatabaseInstanceCloudProviderConfigAwsOutputReference | FederatedDatabaseInstanceCloudProviderConfigAws): any;
export declare class FederatedDatabaseInstanceCloudProviderConfigAwsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FederatedDatabaseInstanceCloudProviderConfigAws | undefined;
    set internalValue(value: FederatedDatabaseInstanceCloudProviderConfigAws | undefined);
    get externalId(): string;
    get iamAssumedRoleArn(): string;
    get iamUserArn(): string;
    private _roleId?;
    get roleId(): string;
    set roleId(value: string);
    get roleIdInput(): string | undefined;
    private _testS3Bucket?;
    get testS3Bucket(): string;
    set testS3Bucket(value: string);
    get testS3BucketInput(): string | undefined;
}
export interface FederatedDatabaseInstanceCloudProviderConfig {
    /**
    * aws block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#aws FederatedDatabaseInstance#aws}
    */
    readonly aws: FederatedDatabaseInstanceCloudProviderConfigAws;
}
export declare function federatedDatabaseInstanceCloudProviderConfigToTerraform(struct?: FederatedDatabaseInstanceCloudProviderConfigOutputReference | FederatedDatabaseInstanceCloudProviderConfig): any;
export declare function federatedDatabaseInstanceCloudProviderConfigToHclTerraform(struct?: FederatedDatabaseInstanceCloudProviderConfigOutputReference | FederatedDatabaseInstanceCloudProviderConfig): any;
export declare class FederatedDatabaseInstanceCloudProviderConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FederatedDatabaseInstanceCloudProviderConfig | undefined;
    set internalValue(value: FederatedDatabaseInstanceCloudProviderConfig | undefined);
    private _aws;
    get aws(): FederatedDatabaseInstanceCloudProviderConfigAwsOutputReference;
    putAws(value: FederatedDatabaseInstanceCloudProviderConfigAws): void;
    get awsInput(): FederatedDatabaseInstanceCloudProviderConfigAws | undefined;
}
export interface FederatedDatabaseInstanceDataProcessRegion {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#cloud_provider FederatedDatabaseInstance#cloud_provider}
    */
    readonly cloudProvider: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#region FederatedDatabaseInstance#region}
    */
    readonly region: string;
}
export declare function federatedDatabaseInstanceDataProcessRegionToTerraform(struct?: FederatedDatabaseInstanceDataProcessRegionOutputReference | FederatedDatabaseInstanceDataProcessRegion): any;
export declare function federatedDatabaseInstanceDataProcessRegionToHclTerraform(struct?: FederatedDatabaseInstanceDataProcessRegionOutputReference | FederatedDatabaseInstanceDataProcessRegion): any;
export declare class FederatedDatabaseInstanceDataProcessRegionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FederatedDatabaseInstanceDataProcessRegion | undefined;
    set internalValue(value: FederatedDatabaseInstanceDataProcessRegion | undefined);
    private _cloudProvider?;
    get cloudProvider(): string;
    set cloudProvider(value: string);
    get cloudProviderInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
}
export interface FederatedDatabaseInstanceStorageDatabasesCollectionsDataSources {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#allow_insecure FederatedDatabaseInstance#allow_insecure}
    */
    readonly allowInsecure?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#collection FederatedDatabaseInstance#collection}
    */
    readonly collection?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#collection_regex FederatedDatabaseInstance#collection_regex}
    */
    readonly collectionRegex?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#database FederatedDatabaseInstance#database}
    */
    readonly database?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#database_regex FederatedDatabaseInstance#database_regex}
    */
    readonly databaseRegex?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#dataset_name FederatedDatabaseInstance#dataset_name}
    */
    readonly datasetName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#default_format FederatedDatabaseInstance#default_format}
    */
    readonly defaultFormat?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#path FederatedDatabaseInstance#path}
    */
    readonly path?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#provenance_field_name FederatedDatabaseInstance#provenance_field_name}
    */
    readonly provenanceFieldName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#store_name FederatedDatabaseInstance#store_name}
    */
    readonly storeName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#urls FederatedDatabaseInstance#urls}
    */
    readonly urls?: string[];
}
export declare function federatedDatabaseInstanceStorageDatabasesCollectionsDataSourcesToTerraform(struct?: FederatedDatabaseInstanceStorageDatabasesCollectionsDataSources | cdktf.IResolvable): any;
export declare function federatedDatabaseInstanceStorageDatabasesCollectionsDataSourcesToHclTerraform(struct?: FederatedDatabaseInstanceStorageDatabasesCollectionsDataSources | cdktf.IResolvable): any;
export declare class FederatedDatabaseInstanceStorageDatabasesCollectionsDataSourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FederatedDatabaseInstanceStorageDatabasesCollectionsDataSources | cdktf.IResolvable | undefined;
    set internalValue(value: FederatedDatabaseInstanceStorageDatabasesCollectionsDataSources | cdktf.IResolvable | undefined);
    private _allowInsecure?;
    get allowInsecure(): boolean | cdktf.IResolvable;
    set allowInsecure(value: boolean | cdktf.IResolvable);
    resetAllowInsecure(): void;
    get allowInsecureInput(): boolean | cdktf.IResolvable | undefined;
    private _collection?;
    get collection(): string;
    set collection(value: string);
    resetCollection(): void;
    get collectionInput(): string | undefined;
    private _collectionRegex?;
    get collectionRegex(): string;
    set collectionRegex(value: string);
    resetCollectionRegex(): void;
    get collectionRegexInput(): string | undefined;
    private _database?;
    get database(): string;
    set database(value: string);
    resetDatabase(): void;
    get databaseInput(): string | undefined;
    private _databaseRegex?;
    get databaseRegex(): string;
    set databaseRegex(value: string);
    resetDatabaseRegex(): void;
    get databaseRegexInput(): string | undefined;
    private _datasetName?;
    get datasetName(): string;
    set datasetName(value: string);
    resetDatasetName(): void;
    get datasetNameInput(): string | undefined;
    private _defaultFormat?;
    get defaultFormat(): string;
    set defaultFormat(value: string);
    resetDefaultFormat(): void;
    get defaultFormatInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _provenanceFieldName?;
    get provenanceFieldName(): string;
    set provenanceFieldName(value: string);
    resetProvenanceFieldName(): void;
    get provenanceFieldNameInput(): string | undefined;
    private _storeName?;
    get storeName(): string;
    set storeName(value: string);
    resetStoreName(): void;
    get storeNameInput(): string | undefined;
    private _urls?;
    get urls(): string[];
    set urls(value: string[]);
    resetUrls(): void;
    get urlsInput(): string[] | undefined;
}
export declare class FederatedDatabaseInstanceStorageDatabasesCollectionsDataSourcesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FederatedDatabaseInstanceStorageDatabasesCollectionsDataSources[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FederatedDatabaseInstanceStorageDatabasesCollectionsDataSourcesOutputReference;
}
export interface FederatedDatabaseInstanceStorageDatabasesCollections {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#name FederatedDatabaseInstance#name}
    */
    readonly name?: string;
    /**
    * data_sources block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#data_sources FederatedDatabaseInstance#data_sources}
    */
    readonly dataSources?: FederatedDatabaseInstanceStorageDatabasesCollectionsDataSources[] | cdktf.IResolvable;
}
export declare function federatedDatabaseInstanceStorageDatabasesCollectionsToTerraform(struct?: FederatedDatabaseInstanceStorageDatabasesCollections | cdktf.IResolvable): any;
export declare function federatedDatabaseInstanceStorageDatabasesCollectionsToHclTerraform(struct?: FederatedDatabaseInstanceStorageDatabasesCollections | cdktf.IResolvable): any;
export declare class FederatedDatabaseInstanceStorageDatabasesCollectionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FederatedDatabaseInstanceStorageDatabasesCollections | cdktf.IResolvable | undefined;
    set internalValue(value: FederatedDatabaseInstanceStorageDatabasesCollections | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _dataSources;
    get dataSources(): FederatedDatabaseInstanceStorageDatabasesCollectionsDataSourcesList;
    putDataSources(value: FederatedDatabaseInstanceStorageDatabasesCollectionsDataSources[] | cdktf.IResolvable): void;
    resetDataSources(): void;
    get dataSourcesInput(): cdktf.IResolvable | FederatedDatabaseInstanceStorageDatabasesCollectionsDataSources[] | undefined;
}
export declare class FederatedDatabaseInstanceStorageDatabasesCollectionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FederatedDatabaseInstanceStorageDatabasesCollections[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FederatedDatabaseInstanceStorageDatabasesCollectionsOutputReference;
}
export interface FederatedDatabaseInstanceStorageDatabasesViews {
}
export declare function federatedDatabaseInstanceStorageDatabasesViewsToTerraform(struct?: FederatedDatabaseInstanceStorageDatabasesViews | cdktf.IResolvable): any;
export declare function federatedDatabaseInstanceStorageDatabasesViewsToHclTerraform(struct?: FederatedDatabaseInstanceStorageDatabasesViews | cdktf.IResolvable): any;
export declare class FederatedDatabaseInstanceStorageDatabasesViewsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FederatedDatabaseInstanceStorageDatabasesViews | cdktf.IResolvable | undefined;
    set internalValue(value: FederatedDatabaseInstanceStorageDatabasesViews | cdktf.IResolvable | undefined);
    get name(): string;
    get pipeline(): string;
    get source(): string;
}
export declare class FederatedDatabaseInstanceStorageDatabasesViewsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FederatedDatabaseInstanceStorageDatabasesViews[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FederatedDatabaseInstanceStorageDatabasesViewsOutputReference;
}
export interface FederatedDatabaseInstanceStorageDatabases {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#name FederatedDatabaseInstance#name}
    */
    readonly name?: string;
    /**
    * collections block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#collections FederatedDatabaseInstance#collections}
    */
    readonly collections?: FederatedDatabaseInstanceStorageDatabasesCollections[] | cdktf.IResolvable;
    /**
    * views block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#views FederatedDatabaseInstance#views}
    */
    readonly views?: FederatedDatabaseInstanceStorageDatabasesViews[] | cdktf.IResolvable;
}
export declare function federatedDatabaseInstanceStorageDatabasesToTerraform(struct?: FederatedDatabaseInstanceStorageDatabases | cdktf.IResolvable): any;
export declare function federatedDatabaseInstanceStorageDatabasesToHclTerraform(struct?: FederatedDatabaseInstanceStorageDatabases | cdktf.IResolvable): any;
export declare class FederatedDatabaseInstanceStorageDatabasesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FederatedDatabaseInstanceStorageDatabases | cdktf.IResolvable | undefined;
    set internalValue(value: FederatedDatabaseInstanceStorageDatabases | cdktf.IResolvable | undefined);
    get maxWildcardCollections(): number;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _collections;
    get collections(): FederatedDatabaseInstanceStorageDatabasesCollectionsList;
    putCollections(value: FederatedDatabaseInstanceStorageDatabasesCollections[] | cdktf.IResolvable): void;
    resetCollections(): void;
    get collectionsInput(): cdktf.IResolvable | FederatedDatabaseInstanceStorageDatabasesCollections[] | undefined;
    private _views;
    get views(): FederatedDatabaseInstanceStorageDatabasesViewsList;
    putViews(value: FederatedDatabaseInstanceStorageDatabasesViews[] | cdktf.IResolvable): void;
    resetViews(): void;
    get viewsInput(): cdktf.IResolvable | FederatedDatabaseInstanceStorageDatabasesViews[] | undefined;
}
export declare class FederatedDatabaseInstanceStorageDatabasesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FederatedDatabaseInstanceStorageDatabases[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FederatedDatabaseInstanceStorageDatabasesOutputReference;
}
export interface FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTags {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#name FederatedDatabaseInstance#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#value FederatedDatabaseInstance#value}
    */
    readonly value?: string;
}
export declare function federatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTagsToTerraform(struct?: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTags | cdktf.IResolvable): any;
export declare function federatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTagsToHclTerraform(struct?: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTags | cdktf.IResolvable): any;
export declare class FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTagsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTags | cdktf.IResolvable | undefined;
    set internalValue(value: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTags | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTagsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTags[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTagsOutputReference;
}
export interface FederatedDatabaseInstanceStorageStoresReadPreferenceTagSets {
    /**
    * tags block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#tags FederatedDatabaseInstance#tags}
    */
    readonly tags: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTags[] | cdktf.IResolvable;
}
export declare function federatedDatabaseInstanceStorageStoresReadPreferenceTagSetsToTerraform(struct?: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSets | cdktf.IResolvable): any;
export declare function federatedDatabaseInstanceStorageStoresReadPreferenceTagSetsToHclTerraform(struct?: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSets | cdktf.IResolvable): any;
export declare class FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FederatedDatabaseInstanceStorageStoresReadPreferenceTagSets | cdktf.IResolvable | undefined;
    set internalValue(value: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSets | cdktf.IResolvable | undefined);
    private _tags;
    get tags(): FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTagsList;
    putTags(value: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTags[] | cdktf.IResolvable): void;
    get tagsInput(): cdktf.IResolvable | FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsTags[] | undefined;
}
export declare class FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSets[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsOutputReference;
}
export interface FederatedDatabaseInstanceStorageStoresReadPreference {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#max_staleness_seconds FederatedDatabaseInstance#max_staleness_seconds}
    */
    readonly maxStalenessSeconds?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#mode FederatedDatabaseInstance#mode}
    */
    readonly mode?: string;
    /**
    * tag_sets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#tag_sets FederatedDatabaseInstance#tag_sets}
    */
    readonly tagSets?: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSets[] | cdktf.IResolvable;
}
export declare function federatedDatabaseInstanceStorageStoresReadPreferenceToTerraform(struct?: FederatedDatabaseInstanceStorageStoresReadPreferenceOutputReference | FederatedDatabaseInstanceStorageStoresReadPreference): any;
export declare function federatedDatabaseInstanceStorageStoresReadPreferenceToHclTerraform(struct?: FederatedDatabaseInstanceStorageStoresReadPreferenceOutputReference | FederatedDatabaseInstanceStorageStoresReadPreference): any;
export declare class FederatedDatabaseInstanceStorageStoresReadPreferenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FederatedDatabaseInstanceStorageStoresReadPreference | undefined;
    set internalValue(value: FederatedDatabaseInstanceStorageStoresReadPreference | undefined);
    private _maxStalenessSeconds?;
    get maxStalenessSeconds(): number;
    set maxStalenessSeconds(value: number);
    resetMaxStalenessSeconds(): void;
    get maxStalenessSecondsInput(): number | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _tagSets;
    get tagSets(): FederatedDatabaseInstanceStorageStoresReadPreferenceTagSetsList;
    putTagSets(value: FederatedDatabaseInstanceStorageStoresReadPreferenceTagSets[] | cdktf.IResolvable): void;
    resetTagSets(): void;
    get tagSetsInput(): cdktf.IResolvable | FederatedDatabaseInstanceStorageStoresReadPreferenceTagSets[] | undefined;
}
export interface FederatedDatabaseInstanceStorageStores {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#additional_storage_classes FederatedDatabaseInstance#additional_storage_classes}
    */
    readonly additionalStorageClasses?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#allow_insecure FederatedDatabaseInstance#allow_insecure}
    */
    readonly allowInsecure?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#bucket FederatedDatabaseInstance#bucket}
    */
    readonly bucket?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#cluster_name FederatedDatabaseInstance#cluster_name}
    */
    readonly clusterName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#default_format FederatedDatabaseInstance#default_format}
    */
    readonly defaultFormat?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#delimiter FederatedDatabaseInstance#delimiter}
    */
    readonly delimiter?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#include_tags FederatedDatabaseInstance#include_tags}
    */
    readonly includeTags?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#name FederatedDatabaseInstance#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#prefix FederatedDatabaseInstance#prefix}
    */
    readonly prefix?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#project_id FederatedDatabaseInstance#project_id}
    */
    readonly projectId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#provider FederatedDatabaseInstance#provider}
    */
    readonly provider?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#public FederatedDatabaseInstance#public}
    */
    readonly public?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#region FederatedDatabaseInstance#region}
    */
    readonly region?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#urls FederatedDatabaseInstance#urls}
    */
    readonly urls?: string[];
    /**
    * read_preference block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#read_preference FederatedDatabaseInstance#read_preference}
    */
    readonly readPreference?: FederatedDatabaseInstanceStorageStoresReadPreference;
}
export declare function federatedDatabaseInstanceStorageStoresToTerraform(struct?: FederatedDatabaseInstanceStorageStores | cdktf.IResolvable): any;
export declare function federatedDatabaseInstanceStorageStoresToHclTerraform(struct?: FederatedDatabaseInstanceStorageStores | cdktf.IResolvable): any;
export declare class FederatedDatabaseInstanceStorageStoresOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FederatedDatabaseInstanceStorageStores | cdktf.IResolvable | undefined;
    set internalValue(value: FederatedDatabaseInstanceStorageStores | cdktf.IResolvable | undefined);
    private _additionalStorageClasses?;
    get additionalStorageClasses(): string[];
    set additionalStorageClasses(value: string[]);
    resetAdditionalStorageClasses(): void;
    get additionalStorageClassesInput(): string[] | undefined;
    private _allowInsecure?;
    get allowInsecure(): boolean | cdktf.IResolvable;
    set allowInsecure(value: boolean | cdktf.IResolvable);
    resetAllowInsecure(): void;
    get allowInsecureInput(): boolean | cdktf.IResolvable | undefined;
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    resetBucket(): void;
    get bucketInput(): string | undefined;
    private _clusterName?;
    get clusterName(): string;
    set clusterName(value: string);
    resetClusterName(): void;
    get clusterNameInput(): string | undefined;
    private _defaultFormat?;
    get defaultFormat(): string;
    set defaultFormat(value: string);
    resetDefaultFormat(): void;
    get defaultFormatInput(): string | undefined;
    private _delimiter?;
    get delimiter(): string;
    set delimiter(value: string);
    resetDelimiter(): void;
    get delimiterInput(): string | undefined;
    private _includeTags?;
    get includeTags(): boolean | cdktf.IResolvable;
    set includeTags(value: boolean | cdktf.IResolvable);
    resetIncludeTags(): void;
    get includeTagsInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _prefix?;
    get prefix(): string;
    set prefix(value: string);
    resetPrefix(): void;
    get prefixInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _provider?;
    get provider(): string;
    set provider(value: string);
    resetProvider(): void;
    get providerInput(): string | undefined;
    private _public?;
    get public(): string;
    set public(value: string);
    resetPublic(): void;
    get publicInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _urls?;
    get urls(): string[];
    set urls(value: string[]);
    resetUrls(): void;
    get urlsInput(): string[] | undefined;
    private _readPreference;
    get readPreference(): FederatedDatabaseInstanceStorageStoresReadPreferenceOutputReference;
    putReadPreference(value: FederatedDatabaseInstanceStorageStoresReadPreference): void;
    resetReadPreference(): void;
    get readPreferenceInput(): FederatedDatabaseInstanceStorageStoresReadPreference | undefined;
}
export declare class FederatedDatabaseInstanceStorageStoresList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FederatedDatabaseInstanceStorageStores[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FederatedDatabaseInstanceStorageStoresOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance mongodbatlas_federated_database_instance}
*/
export declare class FederatedDatabaseInstance extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_federated_database_instance";
    /**
    * Generates CDKTF code for importing a FederatedDatabaseInstance resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the FederatedDatabaseInstance to import
    * @param importFromId The id of the existing FederatedDatabaseInstance that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the FederatedDatabaseInstance to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/federated_database_instance mongodbatlas_federated_database_instance} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options FederatedDatabaseInstanceConfig
    */
    constructor(scope: Construct, id: string, config: FederatedDatabaseInstanceConfig);
    get hostnames(): string[];
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    get state(): string;
    private _cloudProviderConfig;
    get cloudProviderConfig(): FederatedDatabaseInstanceCloudProviderConfigOutputReference;
    putCloudProviderConfig(value: FederatedDatabaseInstanceCloudProviderConfig): void;
    resetCloudProviderConfig(): void;
    get cloudProviderConfigInput(): FederatedDatabaseInstanceCloudProviderConfig | undefined;
    private _dataProcessRegion;
    get dataProcessRegion(): FederatedDatabaseInstanceDataProcessRegionOutputReference;
    putDataProcessRegion(value: FederatedDatabaseInstanceDataProcessRegion): void;
    resetDataProcessRegion(): void;
    get dataProcessRegionInput(): FederatedDatabaseInstanceDataProcessRegion | undefined;
    private _storageDatabases;
    get storageDatabases(): FederatedDatabaseInstanceStorageDatabasesList;
    putStorageDatabases(value: FederatedDatabaseInstanceStorageDatabases[] | cdktf.IResolvable): void;
    resetStorageDatabases(): void;
    get storageDatabasesInput(): cdktf.IResolvable | FederatedDatabaseInstanceStorageDatabases[] | undefined;
    private _storageStores;
    get storageStores(): FederatedDatabaseInstanceStorageStoresList;
    putStorageStores(value: FederatedDatabaseInstanceStorageStores[] | cdktf.IResolvable): void;
    resetStorageStores(): void;
    get storageStoresInput(): cdktf.IResolvable | FederatedDatabaseInstanceStorageStores[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
