/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MongodbEmployeeAccessGrantConfig extends cdktf.TerraformMetaArguments {
    /**
    * Human-readable label that identifies this cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/mongodb_employee_access_grant#cluster_name MongodbEmployeeAccessGrant#cluster_name}
    */
    readonly clusterName: string;
    /**
    * Expiration date for the employee access grant.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/mongodb_employee_access_grant#expiration_time MongodbEmployeeAccessGrant#expiration_time}
    */
    readonly expirationTime: string;
    /**
    * Level of access to grant to MongoDB Employees. Possible values are CLUSTER_DATABASE_LOGS, CLUSTER_INFRASTRUCTURE or CLUSTER_INFRASTRUCTURE_AND_APP_SERVICES_SYNC_DATA.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/mongodb_employee_access_grant#grant_type MongodbEmployeeAccessGrant#grant_type}
    */
    readonly grantType: string;
    /**
    * Unique 24-hexadecimal digit string that identifies your project. Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.
    *
    * **NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group/project id remains the same. The resource and corresponding endpoints use the term groups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/mongodb_employee_access_grant#project_id MongodbEmployeeAccessGrant#project_id}
    */
    readonly projectId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/mongodb_employee_access_grant mongodbatlas_mongodb_employee_access_grant}
*/
export declare class MongodbEmployeeAccessGrant extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_mongodb_employee_access_grant";
    /**
    * Generates CDKTF code for importing a MongodbEmployeeAccessGrant resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the MongodbEmployeeAccessGrant to import
    * @param importFromId The id of the existing MongodbEmployeeAccessGrant that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/mongodb_employee_access_grant#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the MongodbEmployeeAccessGrant to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/mongodb_employee_access_grant mongodbatlas_mongodb_employee_access_grant} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MongodbEmployeeAccessGrantConfig
    */
    constructor(scope: Construct, id: string, config: MongodbEmployeeAccessGrantConfig);
    private _clusterName?;
    get clusterName(): string;
    set clusterName(value: string);
    get clusterNameInput(): string | undefined;
    private _expirationTime?;
    get expirationTime(): string;
    set expirationTime(value: string);
    get expirationTimeInput(): string | undefined;
    private _grantType?;
    get grantType(): string;
    set grantType(value: string);
    get grantTypeInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
