/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrganizationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization#api_access_list_required Organization#api_access_list_required}
    */
    readonly apiAccessListRequired?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization#description Organization#description}
    */
    readonly description: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization#federation_settings_id Organization#federation_settings_id}
    */
    readonly federationSettingsId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization#id Organization#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization#multi_factor_auth_required Organization#multi_factor_auth_required}
    */
    readonly multiFactorAuthRequired?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization#name Organization#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization#org_owner_id Organization#org_owner_id}
    */
    readonly orgOwnerId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization#restrict_employee_access Organization#restrict_employee_access}
    */
    readonly restrictEmployeeAccess?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization#role_names Organization#role_names}
    */
    readonly roleNames: string[];
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization mongodbatlas_organization}
*/
export declare class Organization extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_organization";
    /**
    * Generates CDKTF code for importing a Organization resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Organization to import
    * @param importFromId The id of the existing Organization that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Organization to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/organization mongodbatlas_organization} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrganizationConfig
    */
    constructor(scope: Construct, id: string, config: OrganizationConfig);
    private _apiAccessListRequired?;
    get apiAccessListRequired(): boolean | cdktf.IResolvable;
    set apiAccessListRequired(value: boolean | cdktf.IResolvable);
    resetApiAccessListRequired(): void;
    get apiAccessListRequiredInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    private _federationSettingsId?;
    get federationSettingsId(): string;
    set federationSettingsId(value: string);
    resetFederationSettingsId(): void;
    get federationSettingsIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _multiFactorAuthRequired?;
    get multiFactorAuthRequired(): boolean | cdktf.IResolvable;
    set multiFactorAuthRequired(value: boolean | cdktf.IResolvable);
    resetMultiFactorAuthRequired(): void;
    get multiFactorAuthRequiredInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get orgId(): string;
    private _orgOwnerId?;
    get orgOwnerId(): string;
    set orgOwnerId(value: string);
    get orgOwnerIdInput(): string | undefined;
    get privateKey(): string;
    get publicKey(): string;
    private _restrictEmployeeAccess?;
    get restrictEmployeeAccess(): boolean | cdktf.IResolvable;
    set restrictEmployeeAccess(value: boolean | cdktf.IResolvable);
    resetRestrictEmployeeAccess(): void;
    get restrictEmployeeAccessInput(): boolean | cdktf.IResolvable | undefined;
    private _roleNames?;
    get roleNames(): string[];
    set roleNames(value: string[]);
    get roleNamesInput(): string[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
