/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ProjectApiKeyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_api_key#description ProjectApiKey#description}
    */
    readonly description: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_api_key#id ProjectApiKey#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * project_assignment block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_api_key#project_assignment ProjectApiKey#project_assignment}
    */
    readonly projectAssignment: ProjectApiKeyProjectAssignment[] | cdktf.IResolvable;
}
export interface ProjectApiKeyProjectAssignment {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_api_key#project_id ProjectApiKey#project_id}
    */
    readonly projectId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_api_key#role_names ProjectApiKey#role_names}
    */
    readonly roleNames: string[];
}
export declare function projectApiKeyProjectAssignmentToTerraform(struct?: ProjectApiKeyProjectAssignment | cdktf.IResolvable): any;
export declare function projectApiKeyProjectAssignmentToHclTerraform(struct?: ProjectApiKeyProjectAssignment | cdktf.IResolvable): any;
export declare class ProjectApiKeyProjectAssignmentOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ProjectApiKeyProjectAssignment | cdktf.IResolvable | undefined;
    set internalValue(value: ProjectApiKeyProjectAssignment | cdktf.IResolvable | undefined);
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _roleNames?;
    get roleNames(): string[];
    set roleNames(value: string[]);
    get roleNamesInput(): string[] | undefined;
}
export declare class ProjectApiKeyProjectAssignmentList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ProjectApiKeyProjectAssignment[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ProjectApiKeyProjectAssignmentOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_api_key mongodbatlas_project_api_key}
*/
export declare class ProjectApiKey extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_project_api_key";
    /**
    * Generates CDKTF code for importing a ProjectApiKey resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ProjectApiKey to import
    * @param importFromId The id of the existing ProjectApiKey that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_api_key#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ProjectApiKey to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_api_key mongodbatlas_project_api_key} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ProjectApiKeyConfig
    */
    constructor(scope: Construct, id: string, config: ProjectApiKeyConfig);
    get apiKeyId(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get privateKey(): string;
    get publicKey(): string;
    private _projectAssignment;
    get projectAssignment(): ProjectApiKeyProjectAssignmentList;
    putProjectAssignment(value: ProjectApiKeyProjectAssignment[] | cdktf.IResolvable): void;
    get projectAssignmentInput(): cdktf.IResolvable | ProjectApiKeyProjectAssignment[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
