/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ProjectIpAccessListConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list#aws_security_group ProjectIpAccessList#aws_security_group}
    */
    readonly awsSecurityGroup?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list#cidr_block ProjectIpAccessList#cidr_block}
    */
    readonly cidrBlock?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list#comment ProjectIpAccessList#comment}
    */
    readonly comment?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list#ip_address ProjectIpAccessList#ip_address}
    */
    readonly ipAddress?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list#project_id ProjectIpAccessList#project_id}
    */
    readonly projectId: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list#timeouts ProjectIpAccessList#timeouts}
    */
    readonly timeouts?: ProjectIpAccessListTimeouts;
}
export interface ProjectIpAccessListTimeouts {
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Setting a timeout for a Delete operation is only applicable if changes are saved into state before the destroy operation occurs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list#delete ProjectIpAccessList#delete}
    */
    readonly delete?: string;
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Read operations occur during any refresh or planning operation when refresh is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list#read ProjectIpAccessList#read}
    */
    readonly read?: string;
}
export declare function projectIpAccessListTimeoutsToTerraform(struct?: ProjectIpAccessListTimeouts | cdktf.IResolvable): any;
export declare function projectIpAccessListTimeoutsToHclTerraform(struct?: ProjectIpAccessListTimeouts | cdktf.IResolvable): any;
export declare class ProjectIpAccessListTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ProjectIpAccessListTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: ProjectIpAccessListTimeouts | cdktf.IResolvable | undefined);
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list mongodbatlas_project_ip_access_list}
*/
export declare class ProjectIpAccessList extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_project_ip_access_list";
    /**
    * Generates CDKTF code for importing a ProjectIpAccessList resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ProjectIpAccessList to import
    * @param importFromId The id of the existing ProjectIpAccessList that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ProjectIpAccessList to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/project_ip_access_list mongodbatlas_project_ip_access_list} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ProjectIpAccessListConfig
    */
    constructor(scope: Construct, id: string, config: ProjectIpAccessListConfig);
    private _awsSecurityGroup?;
    get awsSecurityGroup(): string;
    set awsSecurityGroup(value: string);
    resetAwsSecurityGroup(): void;
    get awsSecurityGroupInput(): string | undefined;
    private _cidrBlock?;
    get cidrBlock(): string;
    set cidrBlock(value: string);
    resetCidrBlock(): void;
    get cidrBlockInput(): string | undefined;
    private _comment?;
    get comment(): string;
    set comment(value: string);
    resetComment(): void;
    get commentInput(): string | undefined;
    get id(): string;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    resetIpAddress(): void;
    get ipAddressInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _timeouts;
    get timeouts(): ProjectIpAccessListTimeoutsOutputReference;
    putTimeouts(value: ProjectIpAccessListTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | ProjectIpAccessListTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
