/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MongodbatlasProviderConfig {
    /**
    * AWS API Access Key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#aws_access_key_id MongodbatlasProvider#aws_access_key_id}
    */
    readonly awsAccessKeyId?: string;
    /**
    * AWS API Access Secret Key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#aws_secret_access_key MongodbatlasProvider#aws_secret_access_key}
    */
    readonly awsSecretAccessKey?: string;
    /**
    * AWS Security Token Service provided session token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#aws_session_token MongodbatlasProvider#aws_session_token}
    */
    readonly awsSessionToken?: string;
    /**
    * MongoDB Atlas Base URL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#base_url MongodbatlasProvider#base_url}
    */
    readonly baseUrl?: string;
    /**
    * MongoDB Atlas Base URL default to gov
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#is_mongodbgov_cloud MongodbatlasProvider#is_mongodbgov_cloud}
    */
    readonly isMongodbgovCloud?: boolean | cdktf.IResolvable;
    /**
    * MongoDB Atlas Programmatic Private Key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#private_key MongodbatlasProvider#private_key}
    */
    readonly privateKey?: string;
    /**
    * MongoDB Atlas Programmatic Public Key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#public_key MongodbatlasProvider#public_key}
    */
    readonly publicKey?: string;
    /**
    * MongoDB Realm Base URL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#realm_base_url MongodbatlasProvider#realm_base_url}
    */
    readonly realmBaseUrl?: string;
    /**
    * Region where secret is stored as part of AWS Secret Manager.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#region MongodbatlasProvider#region}
    */
    readonly region?: string;
    /**
    * Name of secret stored in AWS Secret Manager.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#secret_name MongodbatlasProvider#secret_name}
    */
    readonly secretName?: string;
    /**
    * AWS Security Token Service endpoint. Required for cross-AWS region or cross-AWS account secrets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#sts_endpoint MongodbatlasProvider#sts_endpoint}
    */
    readonly stsEndpoint?: string;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#alias MongodbatlasProvider#alias}
    */
    readonly alias?: string;
    /**
    * assume_role block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#assume_role MongodbatlasProvider#assume_role}
    */
    readonly assumeRole?: MongodbatlasProviderAssumeRole[] | cdktf.IResolvable;
}
export interface MongodbatlasProviderAssumeRole {
    /**
    * The duration, between 15 minutes and 12 hours, of the role session. Valid time units are ns, us (or µs), ms, s, h, or m.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#duration MongodbatlasProvider#duration}
    */
    readonly duration?: string;
    /**
    * A unique identifier that might be required when you assume a role in another account.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#external_id MongodbatlasProvider#external_id}
    */
    readonly externalId?: string;
    /**
    * IAM Policy JSON describing further restricting permissions for the IAM Role being assumed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#policy MongodbatlasProvider#policy}
    */
    readonly policy?: string;
    /**
    * Amazon Resource Names (ARNs) of IAM Policies describing further restricting permissions for the IAM Role being assumed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#policy_arns MongodbatlasProvider#policy_arns}
    */
    readonly policyArns?: string[];
    /**
    * Amazon Resource Name (ARN) of an IAM Role to assume prior to making API calls.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#role_arn MongodbatlasProvider#role_arn}
    */
    readonly roleArn?: string;
    /**
    * An identifier for the assumed role session.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#session_name MongodbatlasProvider#session_name}
    */
    readonly sessionName?: string;
    /**
    * Source identity specified by the principal assuming the role.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#source_identity MongodbatlasProvider#source_identity}
    */
    readonly sourceIdentity?: string;
    /**
    * Assume role session tags.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#tags MongodbatlasProvider#tags}
    */
    readonly tags?: {
        [key: string]: string;
    };
    /**
    * Assume role session tag keys to pass to any subsequent sessions.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#transitive_tag_keys MongodbatlasProvider#transitive_tag_keys}
    */
    readonly transitiveTagKeys?: string[];
}
export declare function mongodbatlasProviderAssumeRoleToTerraform(struct?: MongodbatlasProviderAssumeRole | cdktf.IResolvable): any;
export declare function mongodbatlasProviderAssumeRoleToHclTerraform(struct?: MongodbatlasProviderAssumeRole | cdktf.IResolvable): any;
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs mongodbatlas}
*/
export declare class MongodbatlasProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "mongodbatlas";
    /**
    * Generates CDKTF code for importing a MongodbatlasProvider resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the MongodbatlasProvider to import
    * @param importFromId The id of the existing MongodbatlasProvider that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the MongodbatlasProvider to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs mongodbatlas} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MongodbatlasProviderConfig = {}
    */
    constructor(scope: Construct, id: string, config?: MongodbatlasProviderConfig);
    private _awsAccessKeyId?;
    get awsAccessKeyId(): string | undefined;
    set awsAccessKeyId(value: string | undefined);
    resetAwsAccessKeyId(): void;
    get awsAccessKeyIdInput(): string | undefined;
    private _awsSecretAccessKey?;
    get awsSecretAccessKey(): string | undefined;
    set awsSecretAccessKey(value: string | undefined);
    resetAwsSecretAccessKey(): void;
    get awsSecretAccessKeyInput(): string | undefined;
    private _awsSessionToken?;
    get awsSessionToken(): string | undefined;
    set awsSessionToken(value: string | undefined);
    resetAwsSessionToken(): void;
    get awsSessionTokenInput(): string | undefined;
    private _baseUrl?;
    get baseUrl(): string | undefined;
    set baseUrl(value: string | undefined);
    resetBaseUrl(): void;
    get baseUrlInput(): string | undefined;
    private _isMongodbgovCloud?;
    get isMongodbgovCloud(): boolean | cdktf.IResolvable | undefined;
    set isMongodbgovCloud(value: boolean | cdktf.IResolvable | undefined);
    resetIsMongodbgovCloud(): void;
    get isMongodbgovCloudInput(): boolean | cdktf.IResolvable | undefined;
    private _privateKey?;
    get privateKey(): string | undefined;
    set privateKey(value: string | undefined);
    resetPrivateKey(): void;
    get privateKeyInput(): string | undefined;
    private _publicKey?;
    get publicKey(): string | undefined;
    set publicKey(value: string | undefined);
    resetPublicKey(): void;
    get publicKeyInput(): string | undefined;
    private _realmBaseUrl?;
    get realmBaseUrl(): string | undefined;
    set realmBaseUrl(value: string | undefined);
    resetRealmBaseUrl(): void;
    get realmBaseUrlInput(): string | undefined;
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _secretName?;
    get secretName(): string | undefined;
    set secretName(value: string | undefined);
    resetSecretName(): void;
    get secretNameInput(): string | undefined;
    private _stsEndpoint?;
    get stsEndpoint(): string | undefined;
    set stsEndpoint(value: string | undefined);
    resetStsEndpoint(): void;
    get stsEndpointInput(): string | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    private _assumeRole?;
    get assumeRole(): MongodbatlasProviderAssumeRole[] | cdktf.IResolvable | undefined;
    set assumeRole(value: MongodbatlasProviderAssumeRole[] | cdktf.IResolvable | undefined);
    resetAssumeRole(): void;
    get assumeRoleInput(): cdktf.IResolvable | MongodbatlasProviderAssumeRole[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
