/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PushBasedLogExportConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the bucket to which the agent sends the logs to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export#bucket_name PushBasedLogExport#bucket_name}
    */
    readonly bucketName: string;
    /**
    * ID of the AWS IAM role that is used to write to the S3 bucket.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export#iam_role_id PushBasedLogExport#iam_role_id}
    */
    readonly iamRoleId: string;
    /**
    * S3 directory in which vector writes in order to store the logs. An empty string denotes the root directory.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export#prefix_path PushBasedLogExport#prefix_path}
    */
    readonly prefixPath?: string;
    /**
    * Unique 24-hexadecimal digit string that identifies your project. Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.
    *
    * **NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group/project id remains the same. The resource and corresponding endpoints use the term groups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export#project_id PushBasedLogExport#project_id}
    */
    readonly projectId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export#timeouts PushBasedLogExport#timeouts}
    */
    readonly timeouts?: PushBasedLogExportTimeouts;
}
export interface PushBasedLogExportTimeouts {
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export#create PushBasedLogExport#create}
    */
    readonly create?: string;
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Setting a timeout for a Delete operation is only applicable if changes are saved into state before the destroy operation occurs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export#delete PushBasedLogExport#delete}
    */
    readonly delete?: string;
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export#update PushBasedLogExport#update}
    */
    readonly update?: string;
}
export declare function pushBasedLogExportTimeoutsToTerraform(struct?: PushBasedLogExportTimeouts | cdktf.IResolvable): any;
export declare function pushBasedLogExportTimeoutsToHclTerraform(struct?: PushBasedLogExportTimeouts | cdktf.IResolvable): any;
export declare class PushBasedLogExportTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PushBasedLogExportTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: PushBasedLogExportTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export mongodbatlas_push_based_log_export}
*/
export declare class PushBasedLogExport extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_push_based_log_export";
    /**
    * Generates CDKTF code for importing a PushBasedLogExport resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the PushBasedLogExport to import
    * @param importFromId The id of the existing PushBasedLogExport that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the PushBasedLogExport to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/push_based_log_export mongodbatlas_push_based_log_export} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PushBasedLogExportConfig
    */
    constructor(scope: Construct, id: string, config: PushBasedLogExportConfig);
    private _bucketName?;
    get bucketName(): string;
    set bucketName(value: string);
    get bucketNameInput(): string | undefined;
    get createDate(): string;
    private _iamRoleId?;
    get iamRoleId(): string;
    set iamRoleId(value: string);
    get iamRoleIdInput(): string | undefined;
    private _prefixPath?;
    get prefixPath(): string;
    set prefixPath(value: string);
    resetPrefixPath(): void;
    get prefixPathInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    get state(): string;
    private _timeouts;
    get timeouts(): PushBasedLogExportTimeoutsOutputReference;
    putTimeouts(value: PushBasedLogExportTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | PushBasedLogExportTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
