/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SearchDeploymentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Label that identifies the cluster to return the search nodes for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment#cluster_name SearchDeployment#cluster_name}
    */
    readonly clusterName: string;
    /**
    * Unique 24-hexadecimal character string that identifies the project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment#project_id SearchDeployment#project_id}
    */
    readonly projectId: string;
    /**
    * List of settings that configure the search nodes for your cluster. This list is currently limited to defining a single element.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment#specs SearchDeployment#specs}
    */
    readonly specs: SearchDeploymentSpecs[] | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment#timeouts SearchDeployment#timeouts}
    */
    readonly timeouts?: SearchDeploymentTimeouts;
}
export interface SearchDeploymentSpecs {
    /**
    * Hardware specification for the search node instance sizes. The [MongoDB Atlas API](https://www.mongodb.com/docs/atlas/reference/api-resources-spec/#tag/Atlas-Search/operation/createAtlasSearchDeployment) describes the valid values. More details can also be found in the [Search Node Documentation](https://www.mongodb.com/docs/atlas/cluster-config/multi-cloud-distribution/#search-tier).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment#instance_size SearchDeployment#instance_size}
    */
    readonly instanceSize: string;
    /**
    * Number of search nodes in the cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment#node_count SearchDeployment#node_count}
    */
    readonly nodeCount: number;
}
export declare function searchDeploymentSpecsToTerraform(struct?: SearchDeploymentSpecs | cdktf.IResolvable): any;
export declare function searchDeploymentSpecsToHclTerraform(struct?: SearchDeploymentSpecs | cdktf.IResolvable): any;
export declare class SearchDeploymentSpecsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SearchDeploymentSpecs | cdktf.IResolvable | undefined;
    set internalValue(value: SearchDeploymentSpecs | cdktf.IResolvable | undefined);
    private _instanceSize?;
    get instanceSize(): string;
    set instanceSize(value: string);
    get instanceSizeInput(): string | undefined;
    private _nodeCount?;
    get nodeCount(): number;
    set nodeCount(value: number);
    get nodeCountInput(): number | undefined;
}
export declare class SearchDeploymentSpecsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SearchDeploymentSpecs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SearchDeploymentSpecsOutputReference;
}
export interface SearchDeploymentTimeouts {
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment#create SearchDeployment#create}
    */
    readonly create?: string;
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Setting a timeout for a Delete operation is only applicable if changes are saved into state before the destroy operation occurs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment#delete SearchDeployment#delete}
    */
    readonly delete?: string;
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment#update SearchDeployment#update}
    */
    readonly update?: string;
}
export declare function searchDeploymentTimeoutsToTerraform(struct?: SearchDeploymentTimeouts | cdktf.IResolvable): any;
export declare function searchDeploymentTimeoutsToHclTerraform(struct?: SearchDeploymentTimeouts | cdktf.IResolvable): any;
export declare class SearchDeploymentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SearchDeploymentTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: SearchDeploymentTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment mongodbatlas_search_deployment}
*/
export declare class SearchDeployment extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_search_deployment";
    /**
    * Generates CDKTF code for importing a SearchDeployment resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SearchDeployment to import
    * @param importFromId The id of the existing SearchDeployment that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SearchDeployment to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/search_deployment mongodbatlas_search_deployment} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SearchDeploymentConfig
    */
    constructor(scope: Construct, id: string, config: SearchDeploymentConfig);
    private _clusterName?;
    get clusterName(): string;
    set clusterName(value: string);
    get clusterNameInput(): string | undefined;
    get id(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _specs;
    get specs(): SearchDeploymentSpecsList;
    putSpecs(value: SearchDeploymentSpecs[] | cdktf.IResolvable): void;
    get specsInput(): cdktf.IResolvable | SearchDeploymentSpecs[] | undefined;
    get stateName(): string;
    private _timeouts;
    get timeouts(): SearchDeploymentTimeoutsOutputReference;
    putTimeouts(value: SearchDeploymentTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | SearchDeploymentTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
