/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface StreamConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#authentication StreamConnection#authentication}
    */
    readonly authentication?: StreamConnectionAuthentication;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#bootstrap_servers StreamConnection#bootstrap_servers}
    */
    readonly bootstrapServers?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#cluster_name StreamConnection#cluster_name}
    */
    readonly clusterName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#config StreamConnection#config}
    */
    readonly config?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#connection_name StreamConnection#connection_name}
    */
    readonly connectionName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#db_role_to_execute StreamConnection#db_role_to_execute}
    */
    readonly dbRoleToExecute?: StreamConnectionDbRoleToExecute;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#instance_name StreamConnection#instance_name}
    */
    readonly instanceName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#project_id StreamConnection#project_id}
    */
    readonly projectId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#security StreamConnection#security}
    */
    readonly security?: StreamConnectionSecurity;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#type StreamConnection#type}
    */
    readonly type: string;
}
export interface StreamConnectionAuthentication {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#mechanism StreamConnection#mechanism}
    */
    readonly mechanism?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#password StreamConnection#password}
    */
    readonly password?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#username StreamConnection#username}
    */
    readonly username?: string;
}
export declare function streamConnectionAuthenticationToTerraform(struct?: StreamConnectionAuthentication | cdktf.IResolvable): any;
export declare function streamConnectionAuthenticationToHclTerraform(struct?: StreamConnectionAuthentication | cdktf.IResolvable): any;
export declare class StreamConnectionAuthenticationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StreamConnectionAuthentication | cdktf.IResolvable | undefined;
    set internalValue(value: StreamConnectionAuthentication | cdktf.IResolvable | undefined);
    private _mechanism?;
    get mechanism(): string;
    set mechanism(value: string);
    resetMechanism(): void;
    get mechanismInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _username?;
    get username(): string;
    set username(value: string);
    resetUsername(): void;
    get usernameInput(): string | undefined;
}
export interface StreamConnectionDbRoleToExecute {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#role StreamConnection#role}
    */
    readonly role: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#type StreamConnection#type}
    */
    readonly type: string;
}
export declare function streamConnectionDbRoleToExecuteToTerraform(struct?: StreamConnectionDbRoleToExecute | cdktf.IResolvable): any;
export declare function streamConnectionDbRoleToExecuteToHclTerraform(struct?: StreamConnectionDbRoleToExecute | cdktf.IResolvable): any;
export declare class StreamConnectionDbRoleToExecuteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StreamConnectionDbRoleToExecute | cdktf.IResolvable | undefined;
    set internalValue(value: StreamConnectionDbRoleToExecute | cdktf.IResolvable | undefined);
    private _role?;
    get role(): string;
    set role(value: string);
    get roleInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface StreamConnectionSecurity {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#broker_public_certificate StreamConnection#broker_public_certificate}
    */
    readonly brokerPublicCertificate?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#protocol StreamConnection#protocol}
    */
    readonly protocol?: string;
}
export declare function streamConnectionSecurityToTerraform(struct?: StreamConnectionSecurity | cdktf.IResolvable): any;
export declare function streamConnectionSecurityToHclTerraform(struct?: StreamConnectionSecurity | cdktf.IResolvable): any;
export declare class StreamConnectionSecurityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StreamConnectionSecurity | cdktf.IResolvable | undefined;
    set internalValue(value: StreamConnectionSecurity | cdktf.IResolvable | undefined);
    private _brokerPublicCertificate?;
    get brokerPublicCertificate(): string;
    set brokerPublicCertificate(value: string);
    resetBrokerPublicCertificate(): void;
    get brokerPublicCertificateInput(): string | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    resetProtocol(): void;
    get protocolInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection mongodbatlas_stream_connection}
*/
export declare class StreamConnection extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_stream_connection";
    /**
    * Generates CDKTF code for importing a StreamConnection resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the StreamConnection to import
    * @param importFromId The id of the existing StreamConnection that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the StreamConnection to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_connection mongodbatlas_stream_connection} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options StreamConnectionConfig
    */
    constructor(scope: Construct, id: string, config: StreamConnectionConfig);
    private _authentication;
    get authentication(): StreamConnectionAuthenticationOutputReference;
    putAuthentication(value: StreamConnectionAuthentication): void;
    resetAuthentication(): void;
    get authenticationInput(): cdktf.IResolvable | StreamConnectionAuthentication | undefined;
    private _bootstrapServers?;
    get bootstrapServers(): string;
    set bootstrapServers(value: string);
    resetBootstrapServers(): void;
    get bootstrapServersInput(): string | undefined;
    private _clusterName?;
    get clusterName(): string;
    set clusterName(value: string);
    resetClusterName(): void;
    get clusterNameInput(): string | undefined;
    private _config?;
    get config(): {
        [key: string]: string;
    };
    set config(value: {
        [key: string]: string;
    });
    resetConfig(): void;
    get configInput(): {
        [key: string]: string;
    } | undefined;
    private _connectionName?;
    get connectionName(): string;
    set connectionName(value: string);
    get connectionNameInput(): string | undefined;
    private _dbRoleToExecute;
    get dbRoleToExecute(): StreamConnectionDbRoleToExecuteOutputReference;
    putDbRoleToExecute(value: StreamConnectionDbRoleToExecute): void;
    resetDbRoleToExecute(): void;
    get dbRoleToExecuteInput(): cdktf.IResolvable | StreamConnectionDbRoleToExecute | undefined;
    get id(): string;
    private _instanceName?;
    get instanceName(): string;
    set instanceName(value: string);
    get instanceNameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _security;
    get security(): StreamConnectionSecurityOutputReference;
    putSecurity(value: StreamConnectionSecurity): void;
    resetSecurity(): void;
    get securityInput(): cdktf.IResolvable | StreamConnectionSecurity | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
