/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface StreamInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_instance#data_process_region StreamInstance#data_process_region}
    */
    readonly dataProcessRegion: StreamInstanceDataProcessRegion;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_instance#instance_name StreamInstance#instance_name}
    */
    readonly instanceName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_instance#project_id StreamInstance#project_id}
    */
    readonly projectId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_instance#stream_config StreamInstance#stream_config}
    */
    readonly streamConfig?: StreamInstanceStreamConfig;
}
export interface StreamInstanceDataProcessRegion {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_instance#cloud_provider StreamInstance#cloud_provider}
    */
    readonly cloudProvider: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_instance#region StreamInstance#region}
    */
    readonly region: string;
}
export declare function streamInstanceDataProcessRegionToTerraform(struct?: StreamInstanceDataProcessRegion | cdktf.IResolvable): any;
export declare function streamInstanceDataProcessRegionToHclTerraform(struct?: StreamInstanceDataProcessRegion | cdktf.IResolvable): any;
export declare class StreamInstanceDataProcessRegionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StreamInstanceDataProcessRegion | cdktf.IResolvable | undefined;
    set internalValue(value: StreamInstanceDataProcessRegion | cdktf.IResolvable | undefined);
    private _cloudProvider?;
    get cloudProvider(): string;
    set cloudProvider(value: string);
    get cloudProviderInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
}
export interface StreamInstanceStreamConfig {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_instance#tier StreamInstance#tier}
    */
    readonly tier?: string;
}
export declare function streamInstanceStreamConfigToTerraform(struct?: StreamInstanceStreamConfig | cdktf.IResolvable): any;
export declare function streamInstanceStreamConfigToHclTerraform(struct?: StreamInstanceStreamConfig | cdktf.IResolvable): any;
export declare class StreamInstanceStreamConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StreamInstanceStreamConfig | cdktf.IResolvable | undefined;
    set internalValue(value: StreamInstanceStreamConfig | cdktf.IResolvable | undefined);
    private _tier?;
    get tier(): string;
    set tier(value: string);
    resetTier(): void;
    get tierInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_instance mongodbatlas_stream_instance}
*/
export declare class StreamInstance extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_stream_instance";
    /**
    * Generates CDKTF code for importing a StreamInstance resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the StreamInstance to import
    * @param importFromId The id of the existing StreamInstance that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_instance#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the StreamInstance to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_instance mongodbatlas_stream_instance} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options StreamInstanceConfig
    */
    constructor(scope: Construct, id: string, config: StreamInstanceConfig);
    private _dataProcessRegion;
    get dataProcessRegion(): StreamInstanceDataProcessRegionOutputReference;
    putDataProcessRegion(value: StreamInstanceDataProcessRegion): void;
    get dataProcessRegionInput(): cdktf.IResolvable | StreamInstanceDataProcessRegion | undefined;
    get hostnames(): string[];
    get id(): string;
    private _instanceName?;
    get instanceName(): string;
    set instanceName(value: string);
    get instanceNameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _streamConfig;
    get streamConfig(): StreamInstanceStreamConfigOutputReference;
    putStreamConfig(value: StreamInstanceStreamConfig): void;
    resetStreamConfig(): void;
    get streamConfigInput(): cdktf.IResolvable | StreamInstanceStreamConfig | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
