/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface StreamProcessorConfig extends cdktf.TerraformMetaArguments {
    /**
    * Human-readable label that identifies the stream instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#instance_name StreamProcessor#instance_name}
    */
    readonly instanceName: string;
    /**
    * Optional configuration for the stream processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#options StreamProcessor#options}
    */
    readonly options?: StreamProcessorOptions;
    /**
    * Stream aggregation pipeline you want to apply to your streaming data. [MongoDB Atlas Docs](https://www.mongodb.com/docs/atlas/atlas-stream-processing/stream-aggregation/#std-label-stream-aggregation) contain more information. Using [jsonencode](https://developer.hashicorp.com/terraform/language/functions/jsonencode) is recommended when settig this attribute. For more details see [Aggregation Pipelines Documentation](https://www.mongodb.com/docs/atlas/atlas-stream-processing/stream-aggregation/)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#pipeline StreamProcessor#pipeline}
    */
    readonly pipeline: string;
    /**
    * Human-readable label that identifies the stream processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#processor_name StreamProcessor#processor_name}
    */
    readonly processorName: string;
    /**
    * Unique 24-hexadecimal digit string that identifies your project. Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.
    *
    * **NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group/project id remains the same. The resource and corresponding endpoints use the term groups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#project_id StreamProcessor#project_id}
    */
    readonly projectId: string;
    /**
    * The state of the stream processor. Commonly occurring states are 'CREATED', 'STARTED', 'STOPPED' and 'FAILED'. Used to start or stop the Stream Processor. Valid values are `CREATED`, `STARTED` or `STOPPED`. When a Stream Processor is created without specifying the state, it will default to `CREATED` state.
    *
    * **NOTE** When a stream processor is created, the only valid states are CREATED or STARTED. A stream processor can be automatically started when creating it if the state is set to STARTED.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#state StreamProcessor#state}
    */
    readonly state?: string;
}
export interface StreamProcessorOptionsDlq {
    /**
    * Name of the collection to use for the DLQ.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#coll StreamProcessor#coll}
    */
    readonly coll: string;
    /**
    * Name of the connection to write DLQ messages to. Must be an Atlas connection.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#connection_name StreamProcessor#connection_name}
    */
    readonly connectionName: string;
    /**
    * Name of the database to use for the DLQ.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#db StreamProcessor#db}
    */
    readonly db: string;
}
export declare function streamProcessorOptionsDlqToTerraform(struct?: StreamProcessorOptionsDlq | cdktf.IResolvable): any;
export declare function streamProcessorOptionsDlqToHclTerraform(struct?: StreamProcessorOptionsDlq | cdktf.IResolvable): any;
export declare class StreamProcessorOptionsDlqOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StreamProcessorOptionsDlq | cdktf.IResolvable | undefined;
    set internalValue(value: StreamProcessorOptionsDlq | cdktf.IResolvable | undefined);
    private _coll?;
    get coll(): string;
    set coll(value: string);
    get collInput(): string | undefined;
    private _connectionName?;
    get connectionName(): string;
    set connectionName(value: string);
    get connectionNameInput(): string | undefined;
    private _db?;
    get db(): string;
    set db(value: string);
    get dbInput(): string | undefined;
}
export interface StreamProcessorOptions {
    /**
    * Dead letter queue for the stream processor. Refer to the [MongoDB Atlas Docs](https://www.mongodb.com/docs/atlas/reference/glossary/#std-term-dead-letter-queue) for more information.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#dlq StreamProcessor#dlq}
    */
    readonly dlq: StreamProcessorOptionsDlq;
}
export declare function streamProcessorOptionsToTerraform(struct?: StreamProcessorOptions | cdktf.IResolvable): any;
export declare function streamProcessorOptionsToHclTerraform(struct?: StreamProcessorOptions | cdktf.IResolvable): any;
export declare class StreamProcessorOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StreamProcessorOptions | cdktf.IResolvable | undefined;
    set internalValue(value: StreamProcessorOptions | cdktf.IResolvable | undefined);
    private _dlq;
    get dlq(): StreamProcessorOptionsDlqOutputReference;
    putDlq(value: StreamProcessorOptionsDlq): void;
    get dlqInput(): cdktf.IResolvable | StreamProcessorOptionsDlq | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor mongodbatlas_stream_processor}
*/
export declare class StreamProcessor extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_stream_processor";
    /**
    * Generates CDKTF code for importing a StreamProcessor resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the StreamProcessor to import
    * @param importFromId The id of the existing StreamProcessor that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the StreamProcessor to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.21.1/docs/resources/stream_processor mongodbatlas_stream_processor} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options StreamProcessorConfig
    */
    constructor(scope: Construct, id: string, config: StreamProcessorConfig);
    get id(): string;
    private _instanceName?;
    get instanceName(): string;
    set instanceName(value: string);
    get instanceNameInput(): string | undefined;
    private _options;
    get options(): StreamProcessorOptionsOutputReference;
    putOptions(value: StreamProcessorOptions): void;
    resetOptions(): void;
    get optionsInput(): cdktf.IResolvable | StreamProcessorOptions | undefined;
    private _pipeline?;
    get pipeline(): string;
    set pipeline(value: string);
    get pipelineInput(): string | undefined;
    private _processorName?;
    get processorName(): string;
    set processorName(value: string);
    get processorNameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _state?;
    get state(): string;
    set state(value: string);
    resetState(): void;
    get stateInput(): string | undefined;
    get stats(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
